"""
.. codeauthor:: Nathan Hertz <nhertz@nrao.edu>

Workspaces testing utilities

Put things here if you'd like them to be available to any given test in the entire system

HOW TO USE:
1. In any given pytest-powered test, add this line below the imports:
pytest_plugins = ["testing.utils.conftest"]
2. All fixtures within this file will now be available for use
3. If you want a non-fixture item from here, you'll have to do a normal Python import
"""

import pytest
from alchemy_mock.mocking import UnifiedAlchemyMagicMock

from workspaces.capability.schema import Capability
from workspaces.capability.services.capability_info import CapabilityInfo


@pytest.fixture(scope="session")
def mock_capability_info():
    """
    Pytest fixture providing a mock capability_info object; mocked object can be used
    like a normal CapabilityInfo instance

    :return: Mock capability_info
    """
    mocked_capability_info = CapabilityInfo(UnifiedAlchemyMagicMock())
    test_capability = Capability(name="null", steps="test", max_jobs=2)
    mocked_capability_info.save_entity(test_capability)

    return mocked_capability_info
